==> ask-cli-1.5.0.tgz: package/lib/lambda/upload.js <==
const fs = require('fs');
const path = require('path');
const tmp = require('tmp');
const archiver = require('archiver');

const initAWS = require('../utils/init-aws');
const profileHelper = require('../utils/profile-helper');

// Public
module.exports.createCommand = (commander) => {
    commander
        .command('upload')
        .usage('<-f|--function <function>> [-s|--src <source>] [-p|--profile <profile>]')
        .description('upload an existing Labmda function')
        .option('-f, --function <function>', 'upload to the specified Lambda function')
        .option('-s, --src <source>', 'upload specified source folder')
        .option('-p, --profile <profile>', 'ask cli profile')
        .action(handle);

    function handle(options) {
        if (!options.function) {
            console.warn('Please input required parameter: function');
            return;
        }
        const awsProfile = profileHelper.getAWSProfile(profileHelper.runtimeProfile(options.profile));
        module.exports.createZip(options.src || process.cwd(), (zipFilePath) => {
            uploadToLambda(options.function, zipFilePath, awsProfile, (err) => {
                if (err) {
                    console.error(`[Error]: Upload Lambda function failed. Error: ${err}`);
                } else {
                    console.log(`Lambda function ${options.function} uploaded successfully.`);
                }
            });
        });
    }
};

module.exports.createZip = (src, callback) => {
    fs.access(src, (fs.constants || fs).W_OK, (err) => {
        if (err) {
            console.error(`File access error. ${err}`);
            process.exit(1);
        }
        if (path.extname(src) === '.zip') {
            console.log('The source file has already been compressed. Skip the zipping.');
            callback(src);
            return;
        }
        const zipFilePath = tmp.tmpNameSync({
            prefix: 'asktemp_',
            postfix: '.zip',
            dir: src
        });
        const writeStream = fs.createWriteStream(zipFilePath);
        const archive = archiver('zip');
        const stats = fs.statSync(src);

        archive.on('error', (archiveErr) => {
            console.error(`Archive error. ${archiveErr}`);
        });
        archive.pipe(writeStream);
        if (stats.isFile()) {
            archive.file(src, { name: path.basename(src) });
        } else if (stats.isDirectory()) {
            archive.glob('**/*', {
                cwd: src,
                ignore: path.basename(zipFilePath)
            }, {});
        }
        archive.finalize();

        writeStream.on('close', () => {
            callback(zipFilePath);
        });
    });
};

// Private
function uploadToLambda(functionName, zipFilePath, awsProfile, callback) {
    const aws = initAWS.initAWS(awsProfile);
    if (!aws) {
        return;
    }
    if (initAWS.isLambdaArn(functionName)) {
        initAWS.setRegionWithLambda(aws, functionName);
    }
    const lambdaClient = new aws.Lambda();
    const params = {
        FunctionName: functionName,
        ZipFile: fs.readFileSync(zipFilePath)
    };

    lambdaClient.updateFunctionCode(params, (err) => {
        fs.unlinkSync(zipFilePath);
        callback(err);
    });
}

==> ask-cli-1.6.0.tgz: package/lib/lambda/upload.js <==
const fs = require('fs');
const path = require('path');
const tmp = require('tmp');
const archiver = require('archiver');

const urlUtils = require('@src/utils/url-utils');
const initAWS = require('../utils/init-aws');
const profileHelper = require('../utils/profile-helper');


// Public
module.exports.createCommand = (commander) => {
    commander
        .command('upload')
        .usage('<-f|--function <function>> [-s|--src <source>] [-p|--profile <profile>]')
        .description('upload an existing Labmda function')
        .option('-f, --function <function>', 'upload to the specified Lambda function')
        .option('-s, --src <source>', 'upload specified source folder')
        .option('-p, --profile <profile>', 'ask cli profile')
        .action(handle);

    function handle(options) {
        if (!options.function) {
            console.warn('Please input required parameter: function');
            return;
        }
        const awsProfile = profileHelper.getAWSProfile(profileHelper.runtimeProfile(options.profile));
        module.exports.createZip(options.src || process.cwd(), (zipFilePath) => {
            uploadToLambda(options.function, zipFilePath, awsProfile, (err) => {
                if (err) {
                    console.error(`[Error]: Upload Lambda function failed. Error: ${err}`);
                } else {
                    console.log(`Lambda function ${options.function} uploaded successfully.`);
                }
            });
        });
    }
};

module.exports.createZip = (src, callback) => {
    fs.access(src, (fs.constants || fs).W_OK, (err) => {
        if (err) {
            console.error(`File access error. ${err}`);
            process.exit(1);
        }
        if (path.extname(src) === '.zip' || path.extname(src) === '.jar') {
            console.log('The source file has already been compressed. Skip the zipping.');
            callback(src);
            return;
        }
        const zipFilePath = tmp.tmpNameSync({
            prefix: 'asktemp_',
            postfix: '.zip',
            dir: src
        });
        const writeStream = fs.createWriteStream(zipFilePath);
        const archive = archiver('zip');
        const stats = fs.statSync(src);

        archive.on('error', (archiveErr) => {
            console.error(`Archive error. ${archiveErr}`);
        });
        archive.pipe(writeStream);
        if (stats.isFile()) {
            archive.file(src, { name: path.basename(src) });
        } else if (stats.isDirectory()) {
            archive.glob('**/*', {
                cwd: src,
                ignore: path.basename(zipFilePath)
            }, {});
        }
        archive.finalize();

        writeStream.on('close', () => {
            callback(zipFilePath);
        });
    });
};

// Private
function uploadToLambda(functionName, zipFilePath, awsProfile, callback) {
    const aws = initAWS.initAWS(awsProfile);
    if (!aws) {
        return;
    }
    if (urlUtils.isLambdaArn(functionName)) {
        initAWS.setRegionWithLambda(aws, functionName);
    }
    const lambdaClient = new aws.Lambda();
    const params = {
        FunctionName: functionName,
        ZipFile: fs.readFileSync(zipFilePath)
    };

    lambdaClient.updateFunctionCode(params, (err) => {
        fs.unlinkSync(zipFilePath);
        callback(err);
    });
}
